    <div class="footer">
        <div style="margin: 8px">
        {% include 'sharing.html' %}
        </div>
        <p class="text-center"> Content licensed under the
           <a href="{{site.reflinks.content_license.url}}">{{site.reflinks.content_license.title}}</a>
        </p> 
    </div>


